==> haskell-hls-floskell-plugin-2.1.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-floskell-plugin-2.1.0.0-GkaMhZjxlet8iSabEg3Fvc
key:                  hls-floskell-plugin-2.1.0.0-GkaMhZjxlet8iSabEg3Fvc
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  32e4de6ed319ee5a8524951653e701de
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.1.0.0-GkaMhZjxlet8iSabEg3Fvc
depends:
    base-4.17.2.1 floskell-0.10.8-I6C0yoxtmT15cXJjOMRpCq
    ghcide-2.1.0.0-A4T03gWlEzb9EYItCjNl9Y
    hls-plugin-api-2.1.0.0-AMziRqdsJgLI3Y5c9qz3lj
    lsp-types-2.0.1.0-CE3fjpZHtMWIRyMgheuymH mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-floskell-plugin-2.1.0.0-32-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-floskell-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-floskell-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-floskell-plugin-2.1.0.0-83JU0UYSem1HOHoLwqxSWI
key:                  hls-floskell-plugin-2.1.0.0-83JU0UYSem1HOHoLwqxSWI
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Floskell code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1b8096d8ab9ab0a322b860db24971a42
exposed:              True
exposed-modules:      Ide.Plugin.Floskell
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-floskell-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-floskell-plugin
hs-libraries:         HShls-floskell-plugin-2.1.0.0-83JU0UYSem1HOHoLwqxSWI
depends:
    base-4.17.2.1 floskell-0.10.8-HLnbu6mPBRE2AGMgIKolXk
    ghcide-2.1.0.0-HjJcIrZ7EZPJxbts2S8m1R
    hls-plugin-api-2.1.0.0-KVOZ1lYMH8RFN5Pm8qtNxk
    lsp-types-2.0.1.0-LZDyFmzp6h5B1iJkURTSir mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-floskell-plugin/html/hls-floskell-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-floskell-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
